import { StatsCompilation } from 'webpack';
export declare class Manifest {
    /**
     * Generated manifest record.
     * @type {Record<string, string>}
     */
    protected manifest: Record<string, string>;
    /**
     * Create a new manifest.
     */
    constructor();
    /**
     * Transform the Webpack stats into the shape we need.
     * @param state Value of webpack stats to json output.
     */
    transform(stats: StatsCompilation): this;
    /**
     * Using this manifest built to string.
     */
    rebuild(): string;
    /**
     * Add the given path to the manifest file.
     * @param paths Need given paths.
     * @param entryName output entry name.
     */
    add(paths: string[] | string, entryName: string): this;
    /**
     * Flatten the generated stats assets into an ollection.
     * @param stats Value of webpack stats to json output.
     */
    flattenAssets(stats: StatsCompilation): Record<string, string | string[]>;
    /**
     * Prepare the provided path for processing.
     * @param path Need normalize path string.
     */
    normalizePath(path: string): string;
}
